Content
=======
This package contains writers for SRU files for the Swedish tax agency
(Skatteverket)
See: SKV 269 Teknisk beskrivning för elektronisk redovisning av Inkomstdeklaration 1 samt bilagor till Inkomstdeklaration 1, 2, 3 och 4

1. infosru.py:
   Writer for info.sru
